@@ -17,7 +17,7 @@ import logging
 from datetime import timedelta
 from json import loads
 from time import sleep
-from typing import Sequence, Optional
+from typing import Sequence, Optional, List, Dict, Union
 
 import requests_cache
 from geocoder import ip, osm, distance
@@ -27,6 +27,7 @@ logging.getLogger("geocoder").setLevel(logging.WARNING)
 logging.getLogger("requests_cache").setLevel(logging.WARNING)
 logging.getLogger("googleapiclient").setLevel(logging.WARNING)
 
+
 class CloudRunRegions:
     def __init__(self, project_id: str, co2_signal_api_key: str) -> None:
         """
@@ -39,7 +40,7 @@ class CloudRunRegions:
 
         self.__all = self.__get_all_regions()
 
-    def __get_all_regions(self) -> list[dict[str, str | float]]:
+    def __get_all_regions(self) -> List[Dict[str, Union[str, float]]]:
         client = build("run", "v1")
         raw = (
             client.projects()
@@ -48,7 +49,7 @@ class CloudRunRegions:
             .execute()["locations"]
         )
 
-        all_regions: list[dict[str, str | float]] = []
+        all_regions: List[Dict[str, Union[str, float]]] = []
         for region in raw:
             try:
                 geojson = osm(region["displayName"]).geojson["features"][0][
@@ -70,22 +71,25 @@ class CloudRunRegions:
         return all_regions
 
     @property
-    def closest(self) -> dict[str, str | float | int]:
+    def closest(self) -> Dict[str, Union[str, float, int]]:
         """
         Return the Google Cloud region closest to this machine.
         :return: A dictionary of data about the closest region.
         """
         geolocation = ip("me").latlng
 
-        here = dict()
-        here["lat"], here["lon"] = geolocation[0], geolocation[1]
+        here = {"lat": geolocation[0], "lon": geolocation[1]}
 
         distances_from_here = [
-            region
-            | {
-                "distance_from_current_location": int(
-                    distance((here["lat"], here["lon"]), (region["lat"], region["lon"]))
-                )
+            {
+                **region,
+                **{
+                    "distance_from_current_location": int(
+                        distance(
+                            (here["lat"], here["lon"]), (region["lat"], region["lon"])
+                        )
+                    )
+                },
             }
             for region in self.__all
         ]
@@ -94,13 +98,14 @@ class CloudRunRegions:
             distances_from_here, key=lambda x: x["distance_from_current_location"]
         )
 
-        return closest | {
-            "carbon_intensity": self.__carbon_intensity(str(closest["id"]))
+        return {
+            **closest,
+            **{"carbon_intensity": self.__carbon_intensity(str(closest["id"]))},
         }
 
     def greenest(
-            self, candidate_regions: Optional[Sequence[str]] = None
-    ) -> dict[str, str | float | int]:
+        self, candidate_regions: Optional[Sequence[str]] = None
+    ) -> Dict[str, Union[str, float, int]]:
         """
         Return the Google Cloud region with the lowest carbon intensity now.
         :param candidate_regions: A sequence of region IDs from which to select the greenest, or None to select from all
@@ -119,13 +124,21 @@ class CloudRunRegions:
         else:
             regions = self.__all
 
-        carbon_intensity_for_candidate_regions: list[dict[str, str | float | int]] = []
+        carbon_intensity_for_candidate_regions: List[
+            Dict[str, Union[str, float, int]]
+        ] = []
 
         for region in regions:
             try:
                 carbon_intensity_for_candidate_regions.append(
-                    region
-                    | {"carbon_intensity": self.__carbon_intensity(str(region["id"]))}
+                    {
+                        **region,
+                        **{
+                            "carbon_intensity": self.__carbon_intensity(
+                                str(region["id"])
+                            )
+                        },
+                    }
                 )
             except LookupError:  # Skip over errors for individual regions.
                 logging.warning(
@@ -133,7 +146,7 @@ class CloudRunRegions:
                 )
 
         if (
-                carbon_intensity_for_candidate_regions == []
+            carbon_intensity_for_candidate_regions == []
         ):  # If all regions failed, throw now.
             raise LookupError(f"Could not get carbon intensity data for any region.")
 
@@ -152,13 +165,15 @@ class CloudRunRegions:
         region_obj = [r for r in self.__all if region == r["id"]][0]
 
         try:
-            session = requests_cache.CachedSession("co2_signal_cache", expire_after=timedelta(hours=1))
+            session = requests_cache.CachedSession(
+                "co2_signal_cache", expire_after=timedelta(hours=1)
+            )
             request = session.get(
                 f"https://api.co2signal.com/v1/latest?lon={region_obj['lon']}&lat={region_obj['lat']}",
                 headers={"auth-token": self.co2_signal_api_key},
             )
             assert (
-                    request.status_code == 200
+                request.status_code == 200
             ), f"Got bad response code {request.status_code} from CO2 Signal API."
         except Exception as e:
             raise ConnectionError(
